<?php

namespace Waggybytes\SimplyRemindMe\Library\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Cache;

class MediaType extends Model
{
    public const string EMAIL_CODE = 'email';
    public const string PUSH_CODE = 'push';
    public const string SMS_CODE = 'sms';
    public const string VOICE_CODE = 'voice';

    protected $fillable = ['code_name', 'name', 'class_handler', 'queue_order'];

    protected $hidden = ['class_handler', 'queue_order', 'created_at', 'updated_at'];

    public static function email()
    {
        return Cache::remember('mediaType.email', 3600, function()
        {
            $email = MediaType::where('code_name', self::EMAIL_CODE)->first();
            if (is_null($email))
            {
                throw new \Exception('Email media type could not be found');
            }

            return $email;
        });
    }

    public static function pushNotification()
    {
        return Cache::remember('mediaType.push', 3600, function()
        {
            $push = MediaType::where('code_name', self::PUSH_CODE)->first();
            if (is_null($push))
            {
                throw new \Exception('Push notification media type could not be found');
            }

            return $push;
        });
    }

    public static function sms()
    {
        return Cache::remember('mediaType.sms', 3600, function()
        {
            $sms = MediaType::where('code_name', self::SMS_CODE)->first();
            if (is_null($sms))
            {
                throw new \Exception('SMS media type could not be found');
            }

            return $sms;
        });
    }

    public static function voice()
    {
        return Cache::remember('mediaType.voice', 3600, function()
        {
            $voice = MediaType::where('code_name', self::VOICE_CODE)->first();
            if (is_null($voice))
            {
                throw new \Exception('Voice media type could not be found');
            }

            return $voice;
        });
    }
}